"""
    Utility routines for managing saved account/username/password information.
    Copyright (C) 2009 Red Hat, Inc

    Author: Gavin Romig-Koch <gavin@redhat.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
"""



class AccountManager:
    class LoginAccount:
        def __init__(self):
            self.username = ""
            self.remember_me = False
            self.get_keyring = False
            self.password = None

    def __init__(self):
        self.accounts = {}

    def addAccount(self,accountName,username):
        if not self.accounts.has_key(accountName):
            self.accounts[accountName] = self.LoginAccount()

        self.accounts[accountName].username = username
        self.accounts[accountName].get_keyring = True

    def hasAccount(self,accountName):
        return self.accounts.has_key(accountName)

    def lookupAccount(self,accountName):
        return self.accounts[accountName]

    def queryLogin(self,accountName):

        if self.accounts.has_key(accountName):
            username = self.accounts[accountName].username
            password = self.accounts[accountName].password
            remember = self.accounts[accountName].get_keyring
        else:
            username = ""
            password = None
            remember = False

        if not username:
            username = ""
        if not password:
            password = ""
        if not remember:
            remember = False

        if remember == True:
            try:
                import gnomekeyring
                items = gnomekeyring.find_items_sync(gnomekeyring.ITEM_GENERIC_SECRET, {"user": username, "server": accountName})    
                password = items[0].secret
            except:
                pass

        return (accountName,username,password,remember)

    def updateLogin(self,accountName,loginResult):

        if not self.accounts.has_key(accountName):
            self.accounts[accountName] = self.LoginAccount()

        if loginResult['remember']:
            try:
                import gnomekeyring
                gnomekeyring.item_create_sync(gnomekeyring.get_default_keyring_sync(), gnomekeyring.ITEM_GENERIC_SECRET, "password for user %s at %s" % (loginResult['username'],accountName), {"user" : loginResult['username'], "server": accountName}, loginResult['password'], True)
                self.accounts[accountName].remember_me = True
                self.accounts[accountName].get_keyring = True
            except:
                pass
        else:
            self.accounts[accountName].remember_me = False
            self.accounts[accountName].username = ""

        self.accounts[accountName].password = loginResult['password']
        self.accounts[accountName].username = loginResult['username']
        
